@@ -1,12 +1,14 @@
 import numpy as np
-from pandas._libs import lib, missing as libmissing
+import pandas as pd
+from pandas._libs import lib
+from pandas._libs import missing as libmissing
 from pandas.api.extensions import ExtensionDtype
-from pandas.core.arrays.integer import IntegerArray
-from pandas.core.arrays.integer import coerce_to_array as coerce_to_int_array
 from pandas.core.arrays.floating import FloatingArray
 from pandas.core.arrays.floating import coerce_to_array as coerce_to_float_array
+from pandas.core.arrays.integer import IntegerArray
+from pandas.core.arrays.integer import coerce_to_array as coerce_to_int_array
 from pandas.util._decorators import cache_readonly
-import pandas as pd
+
 
 class MTZDtype(ExtensionDtype):
     """Base ExtensionDtype for implementing persistent MTZ data types"""
@@ -14,7 +16,9 @@ class MTZDtype(ExtensionDtype):
     @classmethod
     def construct_from_string(cls, string):
         if not isinstance(string, str):
-            raise TypeError(f"'construct_from_string' expects a string, got {type(string)}")
+            raise TypeError(
+                f"'construct_from_string' expects a string, got {type(string)}"
+            )
         elif string != cls.name and string != cls.mtztype:
             raise TypeError(f"Cannot construct a '{cls.__name__}' from '{string}'")
         return cls()
@@ -29,13 +33,12 @@ class MTZInt32Dtype(MTZDtype, pd.Int32Dtype):
             return self
         else:
             return super(pd.Int32Dtype, self)._get_common_dtype(dtypes)
-    
+
     def __repr__(self):
         return self.name
 
 
 class MTZIntegerArray(IntegerArray):
-
     @cache_readonly
     def dtype(self):
         return self._dtype
@@ -58,7 +61,7 @@ class MTZIntegerArray(IntegerArray):
         Convert to a NumPy Array.
 
         If array does not contain any NaN values, will return a np.int32
-        ndarray. If array contains NaN values, will return a ndarray of 
+        ndarray. If array contains NaN values, will return a ndarray of
         object dtype.
 
         Parameters
@@ -112,6 +115,7 @@ class MTZIntegerArray(IntegerArray):
         counts : DataSeries
         """
         from pandas import Index
+
         import reciprocalspaceship as rs
 
         # compute counts on the data with no nans
@@ -143,20 +147,19 @@ class MTZIntegerArray(IntegerArray):
 
 class MTZFloat32Dtype(MTZDtype, pd.Float32Dtype):
     """Base ExtensionDtype class for MTZDtype backed by pd.Float32Dtype"""
-    
+
     def _get_common_dtype(self, dtypes):
         if len(set(dtypes)) == 1:
             # only itself
             return self
         else:
             return super(pd.Float32Dtype, self)._get_common_dtype(dtypes)
-    
+
     def __repr__(self):
         return self.name
 
 
 class MTZFloatArray(FloatingArray):
-
     @cache_readonly
     def dtype(self):
         return self._dtype
@@ -174,7 +177,7 @@ class MTZFloatArray(FloatingArray):
         Convert to a NumPy Array.
 
         If array does not contain any NaN values, will return a np.int32
-        ndarray. If array contains NaN values, will return a ndarray of 
+        ndarray. If array contains NaN values, will return a ndarray of
         object dtype.
 
         Parameters
@@ -209,7 +212,7 @@ class MTZFloatArray(FloatingArray):
             data = self._data.astype(dtype, copy=copy)
 
         return data
-    
+
     def value_counts(self, dropna=True):
         """
         Returns a DataSeries containing counts of each category.
@@ -225,6 +228,7 @@ class MTZFloatArray(FloatingArray):
         counts : DataSeries
         """
         from pandas import Index
+
         import reciprocalspaceship as rs
 
         # compute counts on the data with no nans
