@@ -1,7 +1,9 @@
-import pytest
 import numpy as np
 import pandas as pd
-import  reciprocalspaceship as rs
+import pytest
+
+import reciprocalspaceship as rs
+
 
 @pytest.mark.parametrize("level", [None, ["H", "K", "L"], ["H"]])
 @pytest.mark.parametrize("drop", [True, False])
@@ -23,7 +25,7 @@ def test_reset_index(data_fmodel, level, drop, inplace):
         index_names = ["K", "L"]
         columns = ["H"]
         cache = ["K", "L"]
-        
+
     if inplace:
         assert result is None
         assert data_fmodel.index.names == index_names
@@ -33,7 +35,7 @@ def test_reset_index(data_fmodel, level, drop, inplace):
             else:
                 assert c in data_fmodel.columns
         assert cache == list(data_fmodel._index_dtypes.keys())
-        
+
     else:
         assert id(result) != id(data_fmodel)
         assert result.index.names == index_names
@@ -49,16 +51,22 @@ def test_reset_index(data_fmodel, level, drop, inplace):
         assert cache != list(data_fmodel._index_dtypes.keys())
 
 
-@pytest.mark.parametrize("keys", [
-    ["H", "K", "L"],
-    ["H"],
-    "H",
-    np.arange(168),
-    [np.arange(168)],
-    ["H", np.arange(168), "K"],
-    rs.DataSeries(np.arange(168), name="temp"),
-    [rs.DataSeries(np.arange(168), name="temp", dtype="I"), rs.DataSeries(np.arange(168), name="temp2", dtype="I")]
-])
+@pytest.mark.parametrize(
+    "keys",
+    [
+        ["H", "K", "L"],
+        ["H"],
+        "H",
+        np.arange(168),
+        [np.arange(168)],
+        ["H", np.arange(168), "K"],
+        rs.DataSeries(np.arange(168), name="temp"),
+        [
+            rs.DataSeries(np.arange(168), name="temp", dtype="I"),
+            rs.DataSeries(np.arange(168), name="temp2", dtype="I"),
+        ],
+    ],
+)
 def test_set_index_cache(data_fmodel, keys):
     """
     Test DataSet.set_index() correctly sets DataSet._index_dtypes attribute
